
package mobicomp.hearts.lobby;


import java.util.Observable;
import java.util.Vector;

import mobicomp.hearts.data.Player;


/**
 * This class is the model in the model-view-controller 
 * pattern consisting of LobbyData, LobbyFrame, and LobbyController
 * @author Andreas Wetzel <andi@spamato.net>
 */
public class LobbyData extends Observable
{
    public Player player;

    public Vector openGames = new Vector();
    public Game currentGame = null;
    public boolean isLookingForGames = false;
    public boolean isHostingGame = false;
    public boolean hasJoined = false;

    public LobbyData( Player player) {
        this.player = player;
    }

    /**
     * This method is used to store information about
     * open games. 
     * @param newgame The newly received game object
     */
    public void updateOpenGame(Game newgame) {
    	// check if this game is already in the list
        for (int i = 0; i < openGames.size(); i++) {
            Game game = (Game) openGames.get(i);
            if (game.getHostPlayer().equals(newgame.getHostPlayer()) ) {
                openGames.remove(i);
                break;
            }
        }
        openGames.add( newgame);

        // if the updated one is the current selected, also change that reference
        if ((currentGame != null) && (newgame.getHostPlayer().equals( currentGame.getHostPlayer()))) {
            currentGame = newgame;
        }
        notifyObservers();
    }

    /**
     * @see java.util.Observable#notifyObservers()
     */
    public void notifyObservers() {
        setChanged();
        super.notifyObservers();
    }

    /**
     * @see java.util.Observable#notifyObservers(java.lang.Object)
     */
    public void notifyObservers(Object arg) {
        setChanged();
        super.notifyObservers(arg);
    }
}